@@ -1,16 +1,16 @@
 #' @export
-store_new.torch <- function(class, file = NULL, resources = NULL) {
+store_new.torch <- function(format, file = NULL, resources = NULL) {
   torch_new(file, resources)
 }
 
 torch_new <- function(file = NULL, resources = NULL) {
   force(file)
   force(resources)
-  enclass(environment(), c("tar_torch", "tar_unexportable", "tar_store"))
+  enclass(environment(), c("tar_torch", "tar_nonexportable", "tar_store"))
 }
 
 #' @export
-store_assert_format_setting.torch <- function(class) {
+store_assert_format_setting.torch <- function(format) {
 }
 
 #' @export
@@ -24,7 +24,7 @@ store_write_path.tar_torch <- function(store, object, path) {
 }
 
 #' @export
-store_serialize_object.tar_torch <- function(store, object) {
+store_marshal_object.tar_torch <- function(store, object) {
   con <- rawConnection(raw(), open = "wr")
   on.exit(close(con))
   torch::torch_save(object, con)
@@ -32,7 +32,7 @@ store_serialize_object.tar_torch <- function(store, object) {
 }
 
 #' @export
-store_unserialize_object.tar_torch <- function(store, object) {
+store_unmarshal_object.tar_torch <- function(store, object) {
   con <- rawConnection(object, open = "r")
   on.exit(close(con))
   torch::torch_load(con)
