@@ -12,6 +12,11 @@
 #' @inheritParams tar_validate
 #' @param destroy Character of length 1, what to destroy. Choices:
 #'   * `"all"`: destroy the entire data store (default: `_targets/`)
+#'     including cloud data.
+#'   * `"cloud"`: just try to delete cloud data, e.g. target data
+#'     from targets with `tar_target(..., repository = "aws")`.
+#'   * `"local"`: all the local files in the data store but nothing
+#'     on the cloud.
 #'   * `"meta"`: just delete the metadata file at `meta/meta` in the
 #'     data store, which invalidates all the targets but keeps the data.
 #'   * `"process"`: just delete the progress data file at
@@ -44,6 +49,8 @@
 tar_destroy <- function(
   destroy = c(
     "all",
+    "cloud",
+    "local",
     "meta",
     "process",
     "progress",
@@ -54,9 +61,15 @@ tar_destroy <- function(
   ask = NULL,
   store = targets::tar_config_get("store")
 ) {
+  if (!file.exists(store)) {
+    return(invisible())
+  }
+  destroy <- match.arg(destroy)
   path <- switch(
-    match.arg(destroy),
+    destroy,
     all = store,
+    local = store,
+    cloud = tempfile(),
     meta = path_meta(store),
     process = path_process(store),
     progress = path_progress(store),
@@ -64,6 +77,10 @@ tar_destroy <- function(
     scratch = path_scratch_dir(store),
     workspaces = path_workspaces_dir(store)
   )
+  if (destroy %in% c("all", "cloud")) {
+    meta <- tar_meta(store = store)
+    tar_delete_cloud(names = meta$name, meta = meta, path_store = store)
+  }
   if (tar_should_delete(path = path, ask = ask)) {
     unlink(path, recursive = TRUE)
   }
